@@ -18,48 +18,56 @@ module Options.Applicative.Complicated
 import           Control.Monad.Trans.Except ( runExceptT )
 import           Control.Monad.Trans.Writer ( runWriter, tell )
 import           Options.Applicative
-                   ( CommandFields, Parser, ParserFailure, ParserHelp
-                   , ParserInfo (..), ParserResult (..), (<**>), abortOption
-                   , command, execParserPure, footer, fullDesc
+                   ( Parser, ParserFailure, ParserHelp, ParserResult (..)
+                   , abortOption, command, execParserPure, footer, fullDesc
                    , handleParseResult, header, help, info, infoOption, long
                    , metavar, noBacktrack, prefs, progDesc, showHelpOnEmpty
+                   , hsubparser
                    )
 import           Options.Applicative.Builder.Extra ( showHelpText )
-import           Options.Applicative.Builder.Internal
-                   ( Mod (..), mkCommand, mkParser )
-import           Options.Applicative.Types ( OptReader (..) )
 import           Stack.Prelude
-import           Stack.Types.Config ( AddCommand, GlobalOptsMonoid, Runner )
+import           Stack.Types.AddCommand ( AddCommand )
+import           Stack.Types.GlobalOptsMonoid ( GlobalOptsMonoid )
+import           Stack.Types.Runner ( Runner )
 import           System.Environment ( getArgs )
 
 -- | Generate and execute a complicated options parser.
 complicatedOptions ::
      Version
-  -- ^ numeric version
+     -- ^ numeric version
   -> Maybe String
-  -- ^ version string
+     -- ^ version string
   -> String
-  -- ^ Hpack numeric version, as string
+     -- ^ Hpack numeric version, as string
   -> String
-  -- ^ header
+     -- ^ header
   -> String
-  -- ^ program description (displayed between usage and options listing in the
-  -- help output)
+     -- ^ program description (displayed between usage and options listing in
+     -- the help output)
   -> String
-  -- ^ footer
+     -- ^ footer
   -> Parser GlobalOptsMonoid
-  -- ^ common settings
+     -- ^ common settings
   -> Maybe (  ParserFailure ParserHelp
            -> [String]
            -> IO (GlobalOptsMonoid, (RIO Runner (), GlobalOptsMonoid))
            )
-  -- ^ optional handler for parser failure; 'handleParseResult' is called by
-  -- default
+     -- ^ optional handler for parser failure; 'handleParseResult' is called by
+     -- default
   -> AddCommand
-  -- ^ commands (use 'addCommand')
+     -- ^ commands (use 'addCommand')
   -> IO (GlobalOptsMonoid, RIO Runner ())
-complicatedOptions numericVersion stringVersion numericHpackVersion h pd
-  footerStr commonParser mOnFailure commandParser = do
+complicatedOptions
+    numericVersion
+    stringVersion
+    numericHpackVersion
+    h
+    pd
+    footerStr
+    commonParser
+    mOnFailure
+    commandParser
+  = do
     args <- getArgs
     (a, (b, c)) <- let parserPrefs = prefs $ noBacktrack <> showHelpOnEmpty
                    in  case execParserPure parserPrefs parser args of
@@ -86,19 +94,19 @@ complicatedOptions numericVersion stringVersion numericHpackVersion h pd
     infoOption
       s
       (  long "version"
-      <> help "Show version"
+      <> help "Show version."
       )
   numericVersionOption =
     infoOption
       (versionString numericVersion)
       (  long "numeric-version"
-      <> help "Show only version number"
+      <> help "Show only version number."
       )
   numericHpackVersionOption =
     infoOption
       numericHpackVersion
       (  long "hpack-numeric-version"
-      <> help "Show only Hpack's version number"
+      <> help "Show only Hpack's version number."
       )
 
 -- | Add a command to the options dispatcher.
@@ -119,15 +127,15 @@ addCommand cmd title footerStr constr extendCommon =
 -- | Add a command that takes sub-commands to the options dispatcher.
 addSubCommands ::
      String
-  -- ^ command string
+     -- ^ command string
   -> String
-  -- ^ title of command
+     -- ^ title of command
   -> String
-  -- ^ footer of command help
+     -- ^ footer of command help
   -> Parser GlobalOptsMonoid
-  -- ^ common parser
+     -- ^ common parser
   -> AddCommand
-  -- ^ sub-commands (use 'addCommand')
+     -- ^ sub-commands (use 'addCommand')
   -> AddCommand
 addSubCommands cmd title footerStr commonParser commandParser =
   addCommand'
@@ -160,33 +168,22 @@ addCommand' cmd title footerStr constr commonParser inner =
 -- | Generate a complicated options parser.
 complicatedParser ::
      String
-  -- ^ metavar for the sub-command
+     -- ^ metavar for the sub-command
   -> Parser GlobalOptsMonoid
-  -- ^ common settings
+     -- ^ common settings
   -> AddCommand
-  -- ^ commands (use 'addCommand')
+     -- ^ commands (use 'addCommand')
   -> Parser (GlobalOptsMonoid, (RIO Runner (), GlobalOptsMonoid))
 complicatedParser commandMetavar commonParser commandParser =
   (,)
     <$> commonParser
     <*> case runWriter (runExceptT commandParser) of
-          (Right (), d) -> hsubparser' commandMetavar d
+          (Right (), m) -> hsubparser (m <> metavar commandMetavar)
           (Left b, _) -> pure (b, mempty)
 
--- | Subparser with @--help@ argument. Borrowed with slight modification
--- from Options.Applicative.Extra.
-hsubparser' :: String -> Mod CommandFields a -> Parser a
-hsubparser' commandMetavar m = mkParser d g rdr
- where
-  Mod _ d g = metavar commandMetavar `mappend` m
-  (groupName, cmds, subs) = mkCommand m
-  rdr = CmdReader groupName cmds (fmap add_helper . subs)
-  add_helper pinfo = pinfo
-    { infoParser = infoParser pinfo <**> helpOption }
-
 -- | Non-hidden help option.
 helpOption :: Parser (a -> a)
 helpOption =
   abortOption showHelpText $
        long "help"
-    <> help "Show this help text"
+    <> help "Show this help text."
