@@ -10,6 +10,9 @@ module Stack.Constants
   , buildPlanCacheDir
   , haskellFileExts
   , haskellDefaultPreprocessorExts
+  , stackProgName
+  , stackProgName'
+  , nixProgName
   , stackDotYaml
   , stackWorkEnvVar
   , stackRootEnvVar
@@ -17,7 +20,6 @@ module Stack.Constants
   , stackRootOptionName
   , stackGlobalConfigOptionName
   , pantryRootEnvVar
-  , deprecatedStackRootOptionName
   , inContainerEnvVar
   , inNixShellEnvVar
   , stackProgNameUpper
@@ -35,6 +37,7 @@ module Stack.Constants
   , minTerminalWidth
   , maxTerminalWidth
   , defaultTerminalWidth
+  , osIsMacOS
   , osIsWindows
   , relFileSetupHs
   , relFileSetupLhs
@@ -45,13 +48,17 @@ module Stack.Constants
   , relFileCabalMacrosH
   , relDirBuild
   , relDirBin
+  , relDirGhci
+  , relDirGhciScript
   , relDirPantry
   , relDirPrograms
+  , relDirRoot
   , relDirUpperPrograms
   , relDirStackProgName
   , relDirStackWork
   , relFileReadmeTxt
   , relDirScript
+  , relDirScripts
   , relFileConfigYaml
   , relDirSnapshots
   , relDirGlobalHints
@@ -65,6 +72,7 @@ module Stack.Constants
   , relDirLoadedSnapshotCache
   , bindirSuffix
   , docDirSuffix
+  , htmlDirSuffix
   , relDirHpc
   , relDirLib
   , relDirShare
@@ -88,7 +96,6 @@ module Stack.Constants
   , relDirAll
   , relFilePackageCache
   , relFileDockerfile
-  , relDirHaskellStackGhci
   , relFileGhciScript
   , relDirCombined
   , relFileHpcIndexHtml
@@ -102,6 +109,7 @@ module Stack.Constants
   , relDirDotStackProgName
   , relDirUnderHome
   , relDirSrc
+  , relFileLibcMuslx86_64So1
   , relFileLibtinfoSo5
   , relFileLibtinfoSo6
   , relFileLibncurseswSo6
@@ -118,26 +126,42 @@ module Stack.Constants
   , relFileStackDotTmpDotExe
   , relFileStackDotTmp
   , ghcShowOptionsOutput
+  , ghcBootScript
+  , ghcConfigureScript
+  , ghcConfigureWindows
+  , ghcConfigureMacOS
+  , ghcConfigurePosix
+  , relDirHadrian
+  , relFileHadrianStackDotYaml
   , hadrianScriptsWindows
   , hadrianScriptsPosix
+  , libDirs
   , usrLibDirs
   , testGhcEnvRelFile
   , relFileBuildLock
   , stackDeveloperModeDefault
+  , isStackUploadDisabled
   , globalFooter
+  , gitHubBasicAuthType
+  , gitHubTokenEnvVar
+  , altGitHubTokenEnvVar
+  , hackageBaseUrl
   ) where
 
 import           Data.ByteString.Builder ( byteString )
 import           Data.Char ( toUpper )
 import           Data.FileEmbed ( embedFile, makeRelativeToProject )
 import qualified Data.Set as Set
+import qualified Data.Text as T
 import           Distribution.Package ( mkPackageName )
 import           Hpack.Config ( packageConfig )
 import qualified Language.Haskell.TH.Syntax as TH ( runIO, lift )
-import           Path as FL
+import           Path ( (</>), mkRelDir, mkRelFile, parseAbsFile )
+import           Stack.Constants.StackProgName ( stackProgName )
+import           Stack.Constants.UsrLibDirs ( libDirs, usrLibDirs )
 import           Stack.Prelude
 import           Stack.Types.Compiler ( WhichCompiler (..) )
-import           System.Permissions ( osIsWindows )
+import           System.Permissions ( osIsMacOS, osIsWindows )
 import           System.Process ( readProcess )
 
 -- | Type representing exceptions thrown by functions exported by the
@@ -150,6 +174,14 @@ instance Exception ConstantsException where
   displayException WiredInPackagesNotParsedBug = bugReport "[S-6057]"
     "Parse error in wiredInPackages."
 
+-- | Name of the Stack program.
+stackProgName' :: Text
+stackProgName' = T.pack stackProgName
+
+-- | Name of the Nix package manager command
+nixProgName :: String
+nixProgName = "nix"
+
 -- | Extensions used for Haskell modules. Excludes preprocessor ones.
 haskellFileExts :: [Text]
 haskellFileExts = ["hs", "hsc", "lhs"]
@@ -190,15 +222,6 @@ stackGlobalConfigOptionName = "global-config"
 pantryRootEnvVar :: String
 pantryRootEnvVar = "PANTRY_ROOT"
 
--- | Deprecated option name for the global Stack root.
---
--- Deprecated since stack-1.1.0.
---
--- TODO: Remove occurrences of this variable and use 'stackRootOptionName' only
--- after an appropriate deprecation period.
-deprecatedStackRootOptionName :: String
-deprecatedStackRootOptionName = "global-stack-root"
-
 -- | Environment variable used to indicate Stack is running in container.
 inContainerEnvVar :: String
 inContainerEnvVar = stackProgNameUpper ++ "_IN_CONTAINER"
@@ -230,8 +253,9 @@ wiredInPackages = case mparsed of
     [ "ghc-prim"
       -- A magic package
     , "integer-gmp"
-      -- No longer magic > 1.0.3.0. With GHC 9.2.5 at least, there seems to be
-      -- no problem in using it.
+      -- No longer magic > 1.0.3.0 (GHC >= 9.0) and deprecated in favour of
+      -- ghc-bignum. With GHC 9.6.5 at least, there seems to be no problem in
+      -- using it.
     , "integer-simple"
       -- A magic package
     , "base"
@@ -242,17 +266,20 @@ wiredInPackages = case mparsed of
       -- A magic package
     , "dph-seq"
       -- Deprecated in favour of dph-prim-seq, which does not appear to be
-      -- magic. With GHC 9.2.5 at least, there seems to be no problem in using
+      -- magic. With GHC 9.6.5 at least, there seems to be no problem in using
       -- it.
     , "dph-par"
       --  Deprecated in favour of dph-prim-par, which does not appear to be
-      -- magic. With GHC 9.2.5 at least, there seems to be no problem in using
+      -- magic. With GHC 9.6.5 at least, there seems to be no problem in using
       -- it.
     , "ghc"
       -- A magic package
     , "interactive"
-      -- Could not identify information about this package name. With GHC 9.2.5
-      -- at least, there seems to be no problem in using it.
+      -- Type and class declarations at the GHCi command prompt are treated as
+      -- if they were defined in modules all sharing a common package
+      -- interactive. See 'Note [The interactive package]' at
+      -- https://gitlab.haskell.org/ghc/ghc/-/blob/master/compiler/GHC/Runtime/Context.hs
+      -- With GHC 9.6.5 at least, there seems to be no problem in using it.
     , "ghc-bignum"
       -- A magic package
     ]
@@ -303,8 +330,8 @@ buildPlanDir :: Path Abs Dir -- ^ Stack root
 buildPlanDir = (</> $(mkRelDir "build-plan"))
 
 -- | Path where binary caches of the build plans are stored.
-buildPlanCacheDir
-  :: Path Abs Dir -- ^ Stack root
+buildPlanCacheDir ::
+     Path Abs Dir -- ^ Stack root
   -> Path Abs Dir
 buildPlanCacheDir = (</> $(mkRelDir "build-plan-cache"))
 
@@ -362,12 +389,21 @@ relDirBuild = $(mkRelDir "build")
 relDirBin :: Path Rel Dir
 relDirBin = $(mkRelDir "bin")
 
+relDirGhci :: Path Rel Dir
+relDirGhci = $(mkRelDir "ghci")
+
+relDirGhciScript :: Path Rel Dir
+relDirGhciScript = $(mkRelDir "ghci-script")
+
 relDirPantry :: Path Rel Dir
 relDirPantry = $(mkRelDir "pantry")
 
 relDirPrograms :: Path Rel Dir
 relDirPrograms = $(mkRelDir "programs")
 
+relDirRoot :: Path Rel Dir
+relDirRoot = $(mkRelDir ".")
+
 relDirUpperPrograms :: Path Rel Dir
 relDirUpperPrograms = $(mkRelDir "Programs")
 
@@ -383,6 +419,9 @@ relFileReadmeTxt = $(mkRelFile "README.txt")
 relDirScript :: Path Rel Dir
 relDirScript = $(mkRelDir "script")
 
+relDirScripts :: Path Rel Dir
+relDirScripts = $(mkRelDir "scripts")
+
 relFileConfigYaml :: Path Rel File
 relFileConfigYaml = $(mkRelFile "config.yaml")
 
@@ -424,6 +463,10 @@ bindirSuffix = relDirBin
 docDirSuffix :: Path Rel Dir
 docDirSuffix = $(mkRelDir "doc")
 
+-- | Suffix applied to a path to get the @html@ directory.
+htmlDirSuffix :: Path Rel Dir
+htmlDirSuffix = $(mkRelDir "html")
+
 relDirHpc :: Path Rel Dir
 relDirHpc = $(mkRelDir "hpc")
 
@@ -495,9 +538,6 @@ relFilePackageCache = $(mkRelFile "package.cache")
 relFileDockerfile :: Path Rel File
 relFileDockerfile = $(mkRelFile "Dockerfile")
 
-relDirHaskellStackGhci :: Path Rel Dir
-relDirHaskellStackGhci = $(mkRelDir "haskell-stack-ghci")
-
 relFileGhciScript :: Path Rel File
 relFileGhciScript = $(mkRelFile "ghci-script")
 
@@ -537,6 +577,9 @@ relDirUnderHome = $(mkRelDir "_home")
 relDirSrc :: Path Rel Dir
 relDirSrc = $(mkRelDir "src")
 
+relFileLibcMuslx86_64So1 :: Path Rel File
+relFileLibcMuslx86_64So1 = $(mkRelFile "libc.musl-x86_64.so.1")
+
 relFileLibtinfoSo5 :: Path Rel File
 relFileLibtinfoSo5 = $(mkRelFile "libtinfo.so.5")
 
@@ -588,23 +631,48 @@ ghcShowOptionsOutput :: [String]
 ghcShowOptionsOutput =
   $(TH.runIO (readProcess "ghc" ["--show-options"] "") >>= TH.lift . lines)
 
+-- | Relative paths inside a GHC repo to the boot script.
+ghcBootScript :: Path Rel File
+ghcBootScript = $(mkRelFile "boot")
+
+-- | Relative paths inside a GHC repo to the configure script.
+ghcConfigureScript :: Path Rel File
+ghcConfigureScript = $(mkRelFile "configure")
+
+-- | Command applicable to GHC's configure script on Windows. See:
+-- https://gitlab.haskell.org/ghc/ghc/-/blob/master/hadrian/README.md
+ghcConfigureWindows :: [String]
+ghcConfigureWindows = ["sh", "configure", "--enable-tarballs-autodownload"]
+
+-- | Command applicable to GHC's configure script on macOS. See:
+-- https://gitlab.haskell.org/ghc/ghc/-/blob/master/hadrian/README.md
+ghcConfigureMacOS :: [String]
+ghcConfigureMacOS = ["./configure", "--with-intree-gmp"]
+
+-- | Command applicable to GHC's configure script on non-Windows, non-macOS.
+-- See: https://gitlab.haskell.org/ghc/ghc/-/blob/master/hadrian/README.md
+ghcConfigurePosix :: [String]
+ghcConfigurePosix = ["./configure"]
+
+relDirHadrian :: Path Rel Dir
+relDirHadrian = $(mkRelDir "hadrian")
+
+relFileHadrianStackDotYaml :: Path Rel File
+relFileHadrianStackDotYaml = relDirHadrian </> stackDotYaml
+
 -- | Relative paths inside a GHC repo to the Hadrian build batch script.
 -- The second path is maintained for compatibility with older GHC versions.
 hadrianScriptsWindows :: [Path Rel File]
-hadrianScriptsWindows = [$(mkRelFile "hadrian/build-stack.bat"), $(mkRelFile "hadrian/build.stack.bat")]
+hadrianScriptsWindows =
+  [ $(mkRelFile "hadrian/build-stack.bat")
+  , $(mkRelFile "hadrian/build.stack.bat")
+  ]
 
 -- | Relative paths inside a GHC repo to the Hadrian build shell script
 -- The second path is maintained for compatibility with older GHC versions.
 hadrianScriptsPosix :: [Path Rel File]
-hadrianScriptsPosix = [$(mkRelFile "hadrian/build-stack"), $(mkRelFile "hadrian/build.stack.sh")]
-
--- | Used in Stack.Setup for detecting libtinfo, see comments at use site
-usrLibDirs :: [Path Abs Dir]
-#if WINDOWS
-usrLibDirs = []
-#else
-usrLibDirs = [$(mkAbsDir "/usr/lib"),$(mkAbsDir "/usr/lib64")]
-#endif
+hadrianScriptsPosix =
+  [$(mkRelFile "hadrian/build-stack"), $(mkRelFile "hadrian/build.stack.sh")]
 
 -- | Relative file path for a temporary GHC environment file for tests
 testGhcEnvRelFile :: Path Rel File
@@ -618,7 +686,28 @@ relFileBuildLock = $(mkRelFile "build-lock")
 stackDeveloperModeDefault :: Bool
 stackDeveloperModeDefault = STACK_DEVELOPER_MODE_DEFAULT
 
+-- | What should the default be for stack-developer-mode
+isStackUploadDisabled :: Bool
+isStackUploadDisabled = STACK_DISABLE_STACK_UPLOAD
+
 -- | The footer to the help for Stack's subcommands
 globalFooter :: String
 globalFooter =
   "Command 'stack --help' for global options that apply to all subcommands."
+
+-- | The type for GitHub REST API HTTP \'Basic\' authentication.
+gitHubBasicAuthType :: ByteString
+gitHubBasicAuthType = "Bearer"
+
+-- | Environment variable to hold credentials for GitHub REST API HTTP \'Basic\'
+-- authentication.
+gitHubTokenEnvVar :: String
+gitHubTokenEnvVar = "GH_TOKEN"
+
+-- | Alternate environment variable to hold credentials for GitHub REST API HTTP
+-- \'Basic\' authentication.
+altGitHubTokenEnvVar :: String
+altGitHubTokenEnvVar = "GITHUB_TOKEN"
+
+hackageBaseUrl :: Text
+hackageBaseUrl = "https://hackage.haskell.org/"
