@@ -21,13 +21,14 @@ ghcBuildParser hide = option readGHCBuild
        , "gmp4"
        , "nopie"
        , "tinfo6"
+       , "tinfo6-libc6-pre232"
        , "tinfo6-nopie"
        , "ncurses6"
        , "int-native"
        , "integersimple"
        ]
   <> help "Specialized GHC build, e.g. 'gmp4' or 'standard' (usually \
-          \auto-detected)"
+          \auto-detected)."
   <> hideMods hide
   )
  where
