@@ -1,16 +1,21 @@
 {-# LANGUAGE NoImplicitPrelude #-}
 
+-- | Functions to parse command line arguments for Stack's @sdist@ and @upload@
+-- commands.
 module Stack.Options.SDistParser
  ( sdistOptsParser
  ) where
 
 import           Options.Applicative
-import           Options.Applicative.Builder.Extra
+                   ( Parser, completer, help, idm, long, metavar, strArgument
+                   , strOption, switch
+                   )
+import           Options.Applicative.Builder.Extra ( boolFlags, dirCompleter )
 import           Stack.Prelude
-import           Stack.SDist
+import           Stack.SDist ( SDistOpts (..) )
 import           Stack.Options.HpcReportParser ( pvpBoundsOption )
 
--- | Parser for arguments to `stack sdist`
+-- | Parse command line arguments for Stack's @sdist@ and @upload@ commands.
 sdistOptsParser :: Parser SDistOpts
 sdistOptsParser = SDistOpts
   <$> many (strArgument
@@ -22,14 +27,14 @@ sdistOptsParser = SDistOpts
   <*> buildPackageOption
   <*> optional (strOption
         (  long "tar-dir"
-        <> help "If specified, copy all the tar to this dir"
+        <> help "If specified, copy all the tar to this directory."
         ))
  where
   ignoreCheckSwitch = switch
     (  long "ignore-check"
-    <> help "Do not check package for common mistakes"
+    <> help "Do not check package for common mistakes."
     )
   buildPackageOption = boolFlags False
     "test-tarball"
-    "building of the resulting tarball"
+    "building of the resulting tarball."
     idm
