@@ -5,11 +5,13 @@ module Stack.Options.TestParser
   ) where
 
 import           Options.Applicative
-import           Options.Applicative.Args
+                   ( Parser, auto, flag', help, long, metavar, option )
+import           Options.Applicative.Args ( argsOption )
 import           Options.Applicative.Builder.Extra
-import           Stack.Options.Utils
+                   ( firstBoolFlagsTrue, optionalFirst, optionalFirstFalse )
+import           Stack.Options.Utils ( hideMods )
 import           Stack.Prelude
-import           Stack.Types.Config
+import           Stack.Types.BuildOptsMonoid ( TestOptsMonoid (..) )
 
 -- | Parser for test arguments.
 -- FIXME hide args
@@ -17,18 +19,18 @@ testOptsParser :: Bool -> Parser TestOptsMonoid
 testOptsParser hide0 = TestOptsMonoid
   <$> firstBoolFlagsTrue
         "rerun-tests"
-        "running already successful tests"
+        "running already successful tests."
         hide
   <*> fmap concat (many (argsOption
         (  long "test-arguments"
         <> long "ta"
         <> metavar "TEST_ARGS"
-        <> help "Arguments passed in to the test suite program"
+        <> help "Arguments passed in to the test suite program."
         <> hide
         )))
   <*> optionalFirstFalse (flag' True
         (  long "coverage"
-        <> help "Generate a code coverage report"
+        <> help "Generate a code coverage report."
         <> hide
         ))
   <*> optionalFirstFalse (flag' True
@@ -43,7 +45,7 @@ testOptsParser hide0 = TestOptsMonoid
         ))
   <*> firstBoolFlagsTrue
         "tests-allow-stdin"
-        "allow standard input in test executables"
+        "allow standard input in test executables."
         hide
  where
   hide = hideMods hide0
