@@ -7,21 +7,21 @@ module Stack.Types.CompilerBuild
   , parseCompilerBuild
   ) where
 
-import           Stack.Prelude
-import           Pantry.Internal.AesonExtended ( FromJSON, parseJSON, withText )
+import           Data.Aeson.Types ( FromJSON, parseJSON, withText )
 import           Data.Text as T
+import           Stack.Prelude
 
 data CompilerBuild
-    = CompilerBuildStandard
-    | CompilerBuildSpecialized String
-    deriving (Show)
+  = CompilerBuildStandard
+  | CompilerBuildSpecialized String
+  deriving Show
 
 instance FromJSON CompilerBuild where
-    -- Strange structuring is to give consistent error messages
-    parseJSON =
-        withText
-            "CompilerBuild"
-            (either (fail . show) pure . parseCompilerBuild . T.unpack)
+  -- Strange structuring is to give consistent error messages
+  parseJSON =
+    withText
+      "CompilerBuild"
+      (either (fail . show) pure . parseCompilerBuild . T.unpack)
 
 -- | Descriptive name for compiler build
 compilerBuildName :: CompilerBuild -> String
