@@ -1,9 +1,8 @@
-{-# LANGUAGE NoImplicitPrelude  #-}
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE DeriveGeneric      #-}
-{-# LANGUAGE FlexibleInstances  #-}
-{-# LANGUAGE OverloadedStrings  #-}
-{-# LANGUAGE RecordWildCards    #-}
+{-# LANGUAGE NoImplicitPrelude     #-}
+{-# LANGUAGE DuplicateRecordFields #-}
+{-# LANGUAGE NoFieldSelectors      #-}
+{-# LANGUAGE OverloadedRecordDot   #-}
+{-# LANGUAGE OverloadedStrings     #-}
 
 -- | Docker types.
 
@@ -45,16 +44,23 @@ module Stack.Types.Docker
   , reExecArgName
   ) where
 
+import           Data.Aeson.Types ( FromJSON (..), withText )
+import           Data.Aeson.WarningParser
+                   ( WithJSONWarnings, (..:), (..:?), (..!=), withObjectWarnings
+                   )
 import           Data.List ( intercalate )
 import qualified Data.Text as T
-import           Distribution.System ( Platform (..), OS (..), Arch (..) )
-import           Distribution.Text ( simpleParse, display )
+import           Distribution.System ( Arch (..), OS (..), Platform (..) )
+import           Distribution.Text ( display, simpleParse )
 import           Distribution.Version ( anyVersion )
 import           Generics.Deriving.Monoid ( mappenddefault, memptydefault )
-import           Pantry.Internal.AesonExtended
-import           Path
+import           Path ( parseAbsFile )
+import           Stack.Constants ( stackProgName )
 import           Stack.Prelude hiding ( Display (..) )
 import           Stack.Types.Version
+                   ( IntersectingVersionRange (..), VersionRange
+                   , versionRangeText
+                   )
 import           Text.Read ( Read (..) )
 
 -- | Type representing exceptions thrown by functions exported by the
@@ -236,119 +242,142 @@ instance Exception DockerException where
 
 -- | Docker configuration.
 data DockerOpts = DockerOpts
-  { dockerEnable :: !Bool
+  { enable :: !Bool
      -- ^ Is using Docker enabled?
-  , dockerImage :: !(Either SomeException String)
+  , image :: !(Either SomeException String)
      -- ^ Exact Docker image tag or ID.  Overrides docker-repo-*/tag.
-  , dockerRegistryLogin :: !Bool
+  , registryLogin :: !Bool
      -- ^ Does registry require login for pulls?
-  , dockerRegistryUsername :: !(Maybe String)
+  , registryUsername :: !(Maybe String)
      -- ^ Optional username for Docker registry.
-  , dockerRegistryPassword :: !(Maybe String)
+  , registryPassword :: !(Maybe String)
      -- ^ Optional password for Docker registry.
-  , dockerAutoPull :: !Bool
+  , autoPull :: !Bool
      -- ^ Automatically pull new images.
-  , dockerDetach :: !Bool
+  , detach :: !Bool
      -- ^ Whether to run a detached container
-  , dockerPersist :: !Bool
-     -- ^ Create a persistent container (don't remove it when finished).  Implied by
-     -- `dockerDetach`.
-  , dockerContainerName :: !(Maybe String)
-     -- ^ Container name to use, only makes sense from command-line with `dockerPersist`
-     -- or `dockerDetach`.
-  , dockerNetwork :: !(Maybe String)
+  , persist :: !Bool
+     -- ^ Create a persistent container (don't remove it when finished). Implied
+     -- by `dockerDetach`.
+  , containerName :: !(Maybe String)
+     -- ^ Container name to use, only makes sense from command-line with
+     -- `dockerPersist` or `dockerDetach`.
+  , network :: !(Maybe String)
     -- ^ The network docker uses.
-  , dockerRunArgs :: ![String]
+  , runArgs :: ![String]
      -- ^ Arguments to pass directly to @docker run@.
-  , dockerMount :: ![Mount]
+  , mount :: ![Mount]
      -- ^ Volumes to mount in the container.
-  , dockerMountMode :: !(Maybe String)
+  , mountMode :: !(Maybe String)
      -- ^ Volume mount mode
-  , dockerEnv :: ![String]
+  , env :: ![String]
      -- ^ Environment variables to set in the container.
-  , dockerStackExe :: !(Maybe DockerStackExe)
+  , stackExe :: !(Maybe DockerStackExe)
      -- ^ Location of container-compatible Stack executable
-  , dockerSetUser :: !(Maybe Bool)
+  , setUser :: !(Maybe Bool)
     -- ^ Set in-container user to match host's
-  , dockerRequireDockerVersion :: !VersionRange
+  , requireDockerVersion :: !VersionRange
     -- ^ Require a version of Docker within this range.
   }
-  deriving (Show)
+  deriving Show
 
--- | An uninterpreted representation of docker options.
--- Configurations may be "cascaded" using mappend (left-biased).
+-- | An uninterpreted representation of docker options. Configurations may be
+-- "cascaded" using mappend (left-biased).
 data DockerOptsMonoid = DockerOptsMonoid
-  { dockerMonoidDefaultEnable :: !Any
-     -- ^ Should Docker be defaulted to enabled (does @docker:@ section exist in the config)?
-  , dockerMonoidEnable :: !(First Bool)
-     -- ^ Is using Docker enabled?
-  , dockerMonoidRepoOrImage :: !(First DockerMonoidRepoOrImage)
-     -- ^ Docker repository name (e.g. @fpco/stack-build@ or @fpco/stack-full:lts-2.8@)
-  , dockerMonoidRegistryLogin :: !(First Bool)
-     -- ^ Does registry require login for pulls?
-  , dockerMonoidRegistryUsername :: !(First String)
-     -- ^ Optional username for Docker registry.
-  , dockerMonoidRegistryPassword :: !(First String)
-     -- ^ Optional password for Docker registry.
-  , dockerMonoidAutoPull :: !FirstTrue
-     -- ^ Automatically pull new images.
-  , dockerMonoidDetach :: !FirstFalse
-     -- ^ Whether to run a detached container
-  , dockerMonoidPersist :: !FirstFalse
-     -- ^ Create a persistent container (don't remove it when finished).  Implied by
-     -- `dockerDetach`.
-  , dockerMonoidContainerName :: !(First String)
-     -- ^ Container name to use, only makes sense from command-line with `dockerPersist`
-     -- or `dockerDetach`.
-  , dockerMonoidNetwork :: !(First String)
-     -- ^ See: 'dockerNetwork'
-  , dockerMonoidRunArgs :: ![String]
-     -- ^ Arguments to pass directly to @docker run@
-  , dockerMonoidMount :: ![Mount]
-     -- ^ Volumes to mount in the container
-  , dockerMonoidMountMode :: !(First String)
-     -- ^ Volume mount mode
-  , dockerMonoidEnv :: ![String]
-     -- ^ Environment variables to set in the container
-  , dockerMonoidStackExe :: !(First DockerStackExe)
-     -- ^ Location of container-compatible Stack executable
-  , dockerMonoidSetUser :: !(First Bool)
+  { defaultEnable :: !Any
+    -- ^ Should Docker be defaulted to enabled (does @docker:@ section exist in
+    -- the config)?
+  , enable :: !(First Bool)
+    -- ^ Is using Docker enabled?
+  , repoOrImage :: !(First DockerMonoidRepoOrImage)
+    -- ^ Docker repository name (e.g. @fpco/stack-build@ or
+    -- @fpco/stack-full:lts-2.8@)
+  , registryLogin :: !(First Bool)
+    -- ^ Does registry require login for pulls?
+  , registryUsername :: !(First String)
+    -- ^ Optional username for Docker registry.
+  , registryPassword :: !(First String)
+    -- ^ Optional password for Docker registry.
+  , autoPull :: !FirstTrue
+    -- ^ Automatically pull new images.
+  , detach :: !FirstFalse
+    -- ^ Whether to run a detached container
+  , persist :: !FirstFalse
+    -- ^ Create a persistent container (don't remove it when finished). Implied
+    -- by -- `dockerDetach`.
+  , containerName :: !(First String)
+    -- ^ Container name to use, only makes sense from command-line with
+    -- `dockerPersist` or `dockerDetach`.
+  , network :: !(First String)
+    -- ^ See: 'dockerNetwork'
+  , runArgs :: ![String]
+    -- ^ Arguments to pass directly to @docker run@
+  , mount :: ![Mount]
+    -- ^ Volumes to mount in the container
+  , mountMode :: !(First String)
+    -- ^ Volume mount mode
+  , env :: ![String]
+    -- ^ Environment variables to set in the container
+  , stackExe :: !(First DockerStackExe)
+    -- ^ Location of container-compatible Stack executable
+  , setUser :: !(First Bool)
     -- ^ Set in-container user to match host's
-  , dockerMonoidRequireDockerVersion :: !IntersectingVersionRange
+  , requireDockerVersion :: !IntersectingVersionRange
     -- ^ See: 'dockerRequireDockerVersion'
   }
   deriving (Show, Generic)
 
 -- | Decode uninterpreted docker options from JSON/YAML.
 instance FromJSON (WithJSONWarnings DockerOptsMonoid) where
-  parseJSON = withObjectWarnings "DockerOptsMonoid"
-    (\o -> do
-      let dockerMonoidDefaultEnable = Any True
-      dockerMonoidEnable           <- First <$> o ..:? dockerEnableArgName
-      dockerMonoidRepoOrImage      <- First <$>
-        (   (Just . DockerMonoidImage <$> o ..: dockerImageArgName)
-        <|> (Just . DockerMonoidRepo <$> o ..: dockerRepoArgName)
-        <|> pure Nothing
-        )
-      dockerMonoidRegistryLogin    <- First <$> o ..:? dockerRegistryLoginArgName
-      dockerMonoidRegistryUsername <- First <$> o ..:? dockerRegistryUsernameArgName
-      dockerMonoidRegistryPassword <- First <$> o ..:? dockerRegistryPasswordArgName
-      dockerMonoidAutoPull         <- FirstTrue <$> o ..:? dockerAutoPullArgName
-      dockerMonoidDetach           <- FirstFalse <$> o ..:? dockerDetachArgName
-      dockerMonoidPersist          <- FirstFalse <$> o ..:? dockerPersistArgName
-      dockerMonoidContainerName    <- First <$> o ..:? dockerContainerNameArgName
-      dockerMonoidNetwork          <- First <$> o ..:? dockerNetworkArgName
-      dockerMonoidRunArgs          <- o ..:? dockerRunArgsArgName ..!= []
-      dockerMonoidMount            <- o ..:? dockerMountArgName ..!= []
-      dockerMonoidMountMode        <- First <$> o ..:? dockerMountModeArgName
-      dockerMonoidEnv              <- o ..:? dockerEnvArgName ..!= []
-      dockerMonoidStackExe         <- First <$> o ..:? dockerStackExeArgName
-      dockerMonoidSetUser          <- First <$> o ..:? dockerSetUserArgName
-      dockerMonoidRequireDockerVersion <- IntersectingVersionRange . unVersionRangeJSON <$>
+  parseJSON = withObjectWarnings "DockerOptsMonoid" $ \o -> do
+    let defaultEnable = Any True
+    enable <- First <$> o ..:? dockerEnableArgName
+    repoOrImage <- First <$>
+      (   (Just . DockerMonoidImage <$> o ..: dockerImageArgName)
+      <|> (Just . DockerMonoidRepo <$> o ..: dockerRepoArgName)
+      <|> pure Nothing
+      )
+    registryLogin <- First <$> o ..:? dockerRegistryLoginArgName
+    registryUsername <-
+      First <$> o ..:? dockerRegistryUsernameArgName
+    registryPassword <-
+      First <$> o ..:? dockerRegistryPasswordArgName
+    autoPull <- FirstTrue <$> o ..:? dockerAutoPullArgName
+    detach <- FirstFalse <$> o ..:? dockerDetachArgName
+    persist <- FirstFalse <$> o ..:? dockerPersistArgName
+    containerName <- First <$> o ..:? dockerContainerNameArgName
+    network <- First <$> o ..:? dockerNetworkArgName
+    runArgs <- o ..:? dockerRunArgsArgName ..!= []
+    mount <- o ..:? dockerMountArgName ..!= []
+    mountMode <- First <$> o ..:? dockerMountModeArgName
+    env <- o ..:? dockerEnvArgName ..!= []
+    stackExe <- First <$> o ..:? dockerStackExeArgName
+    setUser <- First <$> o ..:? dockerSetUserArgName
+    requireDockerVersion <-
+      IntersectingVersionRange . (.versionRangeJSON) <$>
         ( o ..:? dockerRequireDockerVersionArgName
           ..!= VersionRangeJSON anyVersion
         )
-      pure DockerOptsMonoid{..})
+    pure DockerOptsMonoid
+      { defaultEnable
+      , enable
+      , repoOrImage
+      , registryLogin
+      , registryUsername
+      , registryPassword
+      , autoPull
+      , detach
+      , persist
+      , containerName
+      , network
+      , runArgs
+      , mount
+      , mountMode
+      , env
+      , stackExe
+      , setUser
+      , requireDockerVersion
+      }
 
 -- | Left-biased combine Docker options
 instance Semigroup DockerOptsMonoid where
@@ -365,7 +394,7 @@ data DockerStackExe
   | DockerStackExeHost  -- ^ Host's `stack` (linux-x86_64 only)
   | DockerStackExeImage  -- ^ Docker image's `stack` (versions must match)
   | DockerStackExePath (Path Abs File) -- ^ Executable at given path
-  deriving (Show)
+  deriving Show
 
 instance FromJSON DockerStackExe where
   parseJSON a = do
@@ -391,15 +420,13 @@ data Mount = Mount String String
 instance Read Mount where
   readsPrec _ s =
     case break (== ':') s of
-      (a,':':b) -> [(Mount a b,"")]
-      (a,[]) -> [(Mount a a,"")]
+      (a, ':':b) -> [(Mount a b, "")]
+      (a, []) -> [(Mount a a, "")]
       _ -> fail "Invalid value for Docker mount (expect '/host/path:/container/path')"
 
 -- | Show instance.
 instance Show Mount where
-  show (Mount a b) = if a == b
-                       then a
-                       else concat [a,":",b]
+  show (Mount a b) = if a == b then a else concat [a, ":", b]
 
 -- | For YAML.
 instance FromJSON Mount where
@@ -413,11 +440,11 @@ instance FromJSON Mount where
 data DockerMonoidRepoOrImage
   = DockerMonoidRepo String
   | DockerMonoidImage String
-  deriving (Show)
+  deriving Show
 
 -- | Newtype for non-orphan FromJSON instance.
 newtype VersionRangeJSON =
-  VersionRangeJSON { unVersionRangeJSON :: VersionRange }
+  VersionRangeJSON { versionRangeJSON :: VersionRange }
 
 -- | Parse VersionRange.
 instance FromJSON VersionRangeJSON where
